const { ethers } = require("hardhat");
const tokenABI = require("../abi/token.json");
const portalABI = require("../abi/portal.json");

async function portalInfo(portalAddr) {
    const provider = ethers.provider;
    const portalContract = new ethers.Contract(portalAddr, portalABI, provider);
    const [gasTokey,decimals] = await portalContract.gasPayingToken()
    console.log("gas token:", gasTokey, " decimals:", decimals);
}

async function bridge(users, portalAddr, tokenAddr) {
    const provider = ethers.provider;
    const portalContract = new ethers.Contract(portalAddr, portalABI, provider);
    const tokenContract = new ethers.Contract(tokenAddr, tokenABI, provider);

    for (let i = 0; i < users.length; i++) {
        const privateKey = users[i]["private"];
        const user = users[i]["address"];
        const value = ethers.parseEther(users[i]["amount"])
        const signer = new ethers.Wallet(privateKey, provider);
        const contractWithSigner = portalContract.connect(signer);
        const usdxWithSigner = tokenContract.connect(signer);

        console.log("bridge token for user:", user)

        const approve = await usdxWithSigner.approve(portalAddr, value);
        await approve.wait();
        console.log("approve token to portal contract tx hash:", approve.hash);

        const nonce = await provider.getTransactionCount(user);
        const deposit = await contractWithSigner.depositERC20Transaction(user, value, value, 250000, false, "0x", {gasPrice:1000000000,gasLimit:10000000,nonce:nonce});
        await deposit.wait();
        console.log("deposit tx hash:", deposit.hash, " for user:", user);
    }
}

async function main() {
    const users = require("../account.json")
    const portalAddr = "0xea2e2269f5d0d327a740dcdc82f4e1c2da8453af";
    const usdxTokenAddr = "0x9C4bd341cF7134A53B1f34cFa9F3dEa4Fde61c9c"
    // await portalInfo(portalAddr);
    await bridge(users, portalAddr, usdxTokenAddr);
}

main()
    .then(() => process.exit(0))
    .catch(error => {
        console.error(error);
        process.exit(1);
    });